==> generator-jhipster-fullcalendar-0.0.2.tgz: package/generators/app/templates/src/main/webapp/app/entities/fullcalendar-event/calendar-event.component.ts <==
import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpHeaders, HttpResponse } from '@angular/common/http';
import { ActivatedRoute } from '@angular/router';
import { Subscription } from 'rxjs';
import { JhiEventManager, JhiParseLinks, JhiDataUtils } from 'ng-jhipster';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';

import { ICalendarEvent } from 'app/shared/model/calendar-event.model';

import { ITEMS_PER_PAGE } from 'app/shared/constants/pagination.constants';
import { CalendarEventService } from './calendar-event.service';
import { CalendarEventDeleteDialogComponent } from './calendar-event-delete-dialog.component';

@Component({
  selector: 'jhi-calendar-event',
  templateUrl: './calendar-event.component.html'
})
export class CalendarEventComponent implements OnInit, OnDestroy {
  calendarEvents: ICalendarEvent[];
  eventSubscriber?: Subscription;
  itemsPerPage: number;
  links: any;
  page: number;
  predicate: string;
  ascending: boolean;
  currentSearch: string;

  constructor(
    protected calendarEventService: CalendarEventService,
    protected dataUtils: JhiDataUtils,
    protected eventManager: JhiEventManager,
    protected modalService: NgbModal,
    protected parseLinks: JhiParseLinks,
    protected activatedRoute: ActivatedRoute
  ) {
    this.calendarEvents = [];
    this.itemsPerPage = ITEMS_PER_PAGE;
    this.page = 0;
    this.links = {
      last: 0
    };
    this.predicate = 'id';
    this.ascending = true;
    this.currentSearch =
      this.activatedRoute.snapshot && this.activatedRoute.snapshot.queryParams['search']
        ? this.activatedRoute.snapshot.queryParams['search']
        : '';
  }

  loadAll(): void {
    if (this.currentSearch) {
      this.calendarEventService
        .search({
          query: this.currentSearch,
          page: this.page,
          size: this.itemsPerPage,
          sort: this.sort()
        })
        .subscribe((res: HttpResponse<ICalendarEvent[]>) => this.paginateCalendarEvents(res.body, res.headers));
      return;
    }

    this.calendarEventService
      .query({
        page: this.page,
        size: this.itemsPerPage,
        sort: this.sort()
      })
      .subscribe((res: HttpResponse<ICalendarEvent[]>) => this.paginateCalendarEvents(res.body, res.headers));
  }

  reset(): void {
    this.page = 0;
    this.calendarEvents = [];
    this.loadAll();
  }

  loadPage(page: number): void {
    this.page = page;
    this.loadAll();
  }

  search(query: string): void {
    this.calendarEvents = [];
    this.links = {
      last: 0
    };
    this.page = 0;
    if (query) {
      this.predicate = '_score';
      this.ascending = false;
    } else {
      this.predicate = 'id';
      this.ascending = true;
    }
    this.currentSearch = query;
    this.loadAll();
  }

  ngOnInit(): void {
    this.loadAll();
    this.registerChangeInCalendarEvents();
  }

  ngOnDestroy(): void {
    if (this.eventSubscriber) {
      this.eventManager.destroy(this.eventSubscriber);
    }
  }

  trackId(index: number, item: ICalendarEvent): number {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
    return item.id!;
  }

  byteSize(base64String: string): string {
    return this.dataUtils.byteSize(base64String);
  }

  openFile(contentType: string, base64String: string): void {
    return this.dataUtils.openFile(contentType, base64String);
  }

  registerChangeInCalendarEvents(): void {
    this.eventSubscriber = this.eventManager.subscribe('calendarEventListModification', () => this.reset());
  }

  delete(calendarEvent: ICalendarEvent): void {
    const modalRef = this.modalService.open(CalendarEventDeleteDialogComponent, { size: 'lg', backdrop: 'static' });
    modalRef.componentInstance.calendarEvent = calendarEvent;
  }

  sort(): string[] {
    const result = [this.predicate + ',' + (this.ascending ? 'asc' : 'desc')];
    if (this.predicate !== 'id') {
      result.push('id');
    }
    return result;
  }

  protected paginateCalendarEvents(data: ICalendarEvent[] | null, headers: HttpHeaders): void {
    const headersLink = headers.get('link');
    this.links = this.parseLinks.parse(headersLink ? headersLink : '');
    if (data) {
      for (let i = 0; i < data.length; i++) {
        this.calendarEvents.push(data[i]);
      }
    }
  }
}

==> generator-jhipster-fullcalendar-0.0.4.tgz: package/generators/app/templates/src/main/webapp/app/entities/fullcalendar-event/calendar-event.component.ts <==
import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpHeaders, HttpResponse } from '@angular/common/http';
import { ActivatedRoute } from '@angular/router';
import { Subscription } from 'rxjs';
import { JhiEventManager, JhiParseLinks, JhiDataUtils } from 'ng-jhipster';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';

import { ICalendarEvent } from 'app/shared/model/fullcalendar-event.model';

import { ITEMS_PER_PAGE } from 'app/shared/constants/pagination.constants';
import { CalendarEventService } from './calendar-event.service';
import { CalendarEventDeleteDialogComponent } from './calendar-event-delete-dialog.component';

@Component({
  selector: 'jhi-calendar-event',
  templateUrl: './calendar-event.component.html'
})
export class CalendarEventComponent implements OnInit, OnDestroy {
  calendarEvents: ICalendarEvent[];
  eventSubscriber?: Subscription;
  itemsPerPage: number;
  links: any;
  page: number;
  predicate: string;
  ascending: boolean;
  currentSearch: string;

  constructor(
    protected calendarEventService: CalendarEventService,
    protected dataUtils: JhiDataUtils,
    protected eventManager: JhiEventManager,
    protected modalService: NgbModal,
    protected parseLinks: JhiParseLinks,
    protected activatedRoute: ActivatedRoute
  ) {
    this.calendarEvents = [];
    this.itemsPerPage = ITEMS_PER_PAGE;
    this.page = 0;
    this.links = {
      last: 0
    };
    this.predicate = 'id';
    this.ascending = true;
    this.currentSearch =
      this.activatedRoute.snapshot && this.activatedRoute.snapshot.queryParams['search']
        ? this.activatedRoute.snapshot.queryParams['search']
        : '';
  }

  loadAll(): void {
    if (this.currentSearch) {
      this.calendarEventService
        .search({
          query: this.currentSearch,
          page: this.page,
          size: this.itemsPerPage,
          sort: this.sort()
        })
        .subscribe((res: HttpResponse<ICalendarEvent[]>) => this.paginateCalendarEvents(res.body, res.headers));
      return;
    }

    this.calendarEventService
      .query({
        page: this.page,
        size: this.itemsPerPage,
        sort: this.sort()
      })
      .subscribe((res: HttpResponse<ICalendarEvent[]>) => this.paginateCalendarEvents(res.body, res.headers));
  }

  reset(): void {
    this.page = 0;
    this.calendarEvents = [];
    this.loadAll();
  }

  loadPage(page: number): void {
    this.page = page;
    this.loadAll();
  }

  search(query: string): void {
    this.calendarEvents = [];
    this.links = {
      last: 0
    };
    this.page = 0;
    if (query) {
      this.predicate = '_score';
      this.ascending = false;
    } else {
      this.predicate = 'id';
      this.ascending = true;
    }
    this.currentSearch = query;
    this.loadAll();
  }

  ngOnInit(): void {
    this.loadAll();
    this.registerChangeInCalendarEvents();
  }

  ngOnDestroy(): void {
    if (this.eventSubscriber) {
      this.eventManager.destroy(this.eventSubscriber);
    }
  }

  trackId(index: number, item: ICalendarEvent): number {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-assertion
    return item.id!;
  }

  byteSize(base64String: string): string {
    return this.dataUtils.byteSize(base64String);
  }

  openFile(contentType: string, base64String: string): void {
    return this.dataUtils.openFile(contentType, base64String);
  }

  registerChangeInCalendarEvents(): void {
    this.eventSubscriber = this.eventManager.subscribe('calendarEventListModification', () => this.reset());
  }

  delete(calendarEvent: ICalendarEvent): void {
    const modalRef = this.modalService.open(CalendarEventDeleteDialogComponent, { size: 'lg', backdrop: 'static' });
    modalRef.componentInstance.calendarEvent = calendarEvent;
  }

  sort(): string[] {
    const result = [this.predicate + ',' + (this.ascending ? 'asc' : 'desc')];
    if (this.predicate !== 'id') {
      result.push('id');
    }
    return result;
  }

  protected paginateCalendarEvents(data: ICalendarEvent[] | null, headers: HttpHeaders): void {
    const headersLink = headers.get('link');
    this.links = this.parseLinks.parse(headersLink ? headersLink : '');
    if (data) {
      for (let i = 0; i < data.length; i++) {
        this.calendarEvents.push(data[i]);
      }
    }
  }
}
